$white: #fff !default;
$white-50: rgba(255, 255, 255, .5) !default;
$gray-100: #f8f9fa !default;
$gray-200: #e9ecef !default;
$gray-300: #dee2e6 !default;
$gray-400: #ced4da !default;
$gray-500: #adb5bd !default;
$gray-600: #6c757d !default;
$gray-700: #495057 !default;
$gray-800: #343a40 !default;
$gray-900: #212529 !default;
$black: #000 !default;
$black-0: rgba(0, 0, 0, 0) !default;
$black-3: rgba(0, 0, 0, .03) !default;
$black-12-5: rgba(0, 0, 0, .125) !default;
$black-15: rgba(0, 0, 0, .15) !default;
$black-50: rgba(0, 0, 0, .5) !default;

// $blue:    #0d6efd !default;
$blue: #007bff !default;
$indigo: #6610f2 !default;
$purple: #6f42c1 !default;
$pink: #d63384 !default;
$red: #dc3545 !default;
$orange: #fd7e14 !default;
$yellow: #ffc107 !default;
// $green:   #198754 !default;
$green: #28a745 !default;
$teal: #20c997 !default;
// $cyan:    #0dcaf0 !default;
$cyan: #17a2b8 !default;

$primary: $blue !default;
$secondary: $gray-600 !default;
$success: $green !default;
$info: $cyan !default;
$warning: $yellow !default;
$danger: $red !default;
$light: $gray-100 !default;
$dark: $gray-800 !default;

// scss-docs-start theme-colors-map
$semantic-colors: (
  "primary": $primary,
  "secondary": $secondary,
  "success": $success,
  "info": $info,
  "warning": $warning,
  "danger": $danger,
  "light": $light,
  "dark": $dark,
) !default;
// scss-docs-end theme-colors-map

@function text-color($name) {
  // color: if(lightness($value) > 70, $gray-900, $white);
  @return if($name == 'light' or $name == 'warning', $gray-900, $white);
}

$btn-focus-width:             .2rem !default;
