// Overrides for non-bootstrap themes (such as alabaster)

.sphinx-bs,
.sphinx-bs * {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

.sphinx-bs p {
  margin-top: 0;
}
